@@ -191,7 +191,8 @@ def viperconsumefromtopic(vipertoken,host,port,topic,consumerid,companyname,part
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,inputdata,enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
+def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,inputdata,algokey='',partition=-1,offset=-1,
+                     enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
                      timeout=120,usedeploy=0,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -201,14 +202,15 @@ def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,cons
          return "Please enter host,port,vipertoken,consumefrom,inputdata,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdepredict?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&delay=" + str(delay) + "&inputdata="+ inputdata + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&inputdata="+ inputdata + "&algokey="+algokey + "&partition="+str(partition)+"&offset="+str(offset)+ "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,delay=100,hpdeport=-999,usedeploy=0,
+def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,offset=-1,
+                      enabletls=0,delay=100,hpdeport=-999,usedeploy=0,
                       ismin=1,constraints='best',stretchbounds=20,constrainttype=1,epsilon=10,brokerhost='',brokerport=9092,
-                     timeout=120,microserviceid=''):
+                      timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
     
@@ -217,12 +219,14 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdeoptimize?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-         "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
+         "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname +
+         "&partition="+str(partition)+"&offset="+str(offset)+
+         "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,modelruns=50,hpdeport=-999,offset=0,islogistic=0,
+def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,modelruns=50,hpdeport=-999,offset=-1,islogistic=0,
                       brokerhost='',brokerport=9092,timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -232,7 +236,8 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdetraining?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&producerid="+producerid + "&companyname="+companyname + "&modelruns="+str(modelruns) +"&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+
+           "&producerid="+producerid + "&companyname="+companyname + "&partition="+str(partition)+"&modelruns="+str(modelruns) +"&hpdehost=" +hpdehost +
+           "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+ "&offset="+str(offset) +
            "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
